==> aws-cdk-lib-2.223.0-sources.jar: software/amazon/awscdk/services/backup/BackupVault.java <==
package software.amazon.awscdk.services.backup;

/**
 * A backup vault.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * IBackupVault importedVault = BackupVault.fromBackupVaultName(this, "Vault", "myVaultName");
 * Role role = Role.Builder.create(this, "Access Role").assumedBy(new ServicePrincipal("lambda.amazonaws.com")).build();
 * importedVault.grant(role, "backup:StartBackupJob");
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.118.0 (build 02eec31)", date = "2025-11-10T13:39:58.986Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_backup.BackupVault")
public class BackupVault extends software.amazon.awscdk.Resource implements software.amazon.awscdk.services.backup.IBackupVault {

    protected BackupVault(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected BackupVault(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        PROPERTY_INJECTION_ID = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.backup.BackupVault.class, "PROPERTY_INJECTION_ID", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public BackupVault(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.backup.BackupVaultProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), props });
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public BackupVault(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required") });
    }

    /**
     * Import an existing backup vault by arn.
     * <p>
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param backupVaultArn This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.backup.IBackupVault fromBackupVaultArn(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String backupVaultArn) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.backup.BackupVault.class, "fromBackupVaultArn", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.backup.IBackupVault.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(backupVaultArn, "backupVaultArn is required") });
    }

    /**
     * Import an existing backup vault by name.
     * <p>
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param backupVaultName This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.backup.IBackupVault fromBackupVaultName(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String backupVaultName) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.backup.BackupVault.class, "fromBackupVaultName", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.backup.IBackupVault.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(backupVaultName, "backupVaultName is required") });
    }

    /**
     * Adds a statement to the vault access policy.
     * <p>
     * @param statement This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void addToAccessPolicy(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.iam.PolicyStatement statement) {
        software.amazon.jsii.Kernel.call(this, "addToAccessPolicy", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(statement, "statement is required") });
    }

    /**
     * Adds a statement to the vault access policy that prevents anyone from deleting a recovery point.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void blockRecoveryPointDeletion() {
        software.amazon.jsii.Kernel.call(this, "blockRecoveryPointDeletion", software.amazon.jsii.NativeType.VOID);
    }

    /**
     * Grant the actions defined in actions to the given grantee on this Backup Vault resource.
     * <p>
     * @param grantee Principal to grant right to. This parameter is required.
     * @param actions The actions to grant. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.iam.Grant grant(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.iam.IGrantable grantee, final @org.jetbrains.annotations.NotNull java.lang.String... actions) {
        return software.amazon.jsii.Kernel.call(this, "grant", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.iam.Grant.class), java.util.stream.Stream.concat(java.util.Arrays.<Object>stream(new Object[] { java.util.Objects.requireNonNull(grantee, "grantee is required") }), java.util.Arrays.<Object>stream(actions)).toArray(Object[]::new));
    }

    /**
     * Uniquely identifies this class.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String PROPERTY_INJECTION_ID;

    /**
     * The ARN of the backup vault.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getBackupVaultArn() {
        return software.amazon.jsii.Kernel.get(this, "backupVaultArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * The name of a logical container where backups are stored.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getBackupVaultName() {
        return software.amazon.jsii.Kernel.get(this, "backupVaultName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.backup.BackupVault}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.backup.BackupVault> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private software.amazon.awscdk.services.backup.BackupVaultProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
        }

        /**
         * A resource-based policy that is used to manage access permissions on the backup vault.
         * <p>
         * Default: - access is not restricted
         * <p>
         * @return {@code this}
         * @param accessPolicy A resource-based policy that is used to manage access permissions on the backup vault. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder accessPolicy(final software.amazon.awscdk.services.iam.PolicyDocument accessPolicy) {
            this.props().accessPolicy(accessPolicy);
            return this;
        }

        /**
         * The name of a logical container where backups are stored.
         * <p>
         * Backup vaults
         * are identified by names that are unique to the account used to create
         * them and the AWS Region where they are created.
         * <p>
         * Default: - A CDK generated name
         * <p>
         * @return {@code this}
         * @param backupVaultName The name of a logical container where backups are stored. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder backupVaultName(final java.lang.String backupVaultName) {
            this.props().backupVaultName(backupVaultName);
            return this;
        }

        /**
         * Whether to add statements to the vault access policy that prevents anyone from deleting a recovery point.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param blockRecoveryPointDeletion Whether to add statements to the vault access policy that prevents anyone from deleting a recovery point. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder blockRecoveryPointDeletion(final java.lang.Boolean blockRecoveryPointDeletion) {
            this.props().blockRecoveryPointDeletion(blockRecoveryPointDeletion);
            return this;
        }

        /**
         * The server-side encryption key to use to protect your backups.
         * <p>
         * Default: - an Amazon managed KMS key
         * <p>
         * @return {@code this}
         * @param encryptionKey The server-side encryption key to use to protect your backups. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder encryptionKey(final software.amazon.awscdk.services.kms.IKeyRef encryptionKey) {
            this.props().encryptionKey(encryptionKey);
            return this;
        }

        /**
         * Configuration for AWS Backup Vault Lock.
         * <p>
         * Default: - AWS Backup Vault Lock is disabled
         * <p>
         * @return {@code this}
         * @see <a href="https://docs.aws.amazon.com/aws-backup/latest/devguide/vault-lock.html">https://docs.aws.amazon.com/aws-backup/latest/devguide/vault-lock.html</a>
         * @param lockConfiguration Configuration for AWS Backup Vault Lock. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder lockConfiguration(final software.amazon.awscdk.services.backup.LockConfiguration lockConfiguration) {
            this.props().lockConfiguration(lockConfiguration);
            return this;
        }

        /**
         * The vault events to send.
         * <p>
         * Default: - all vault events if `notificationTopic` is defined
         * <p>
         * @return {@code this}
         * @see <a href="https://docs.aws.amazon.com/aws-backup/latest/devguide/sns-notifications.html">https://docs.aws.amazon.com/aws-backup/latest/devguide/sns-notifications.html</a>
         * @param notificationEvents The vault events to send. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder notificationEvents(final java.util.List<? extends software.amazon.awscdk.services.backup.BackupVaultEvents> notificationEvents) {
            this.props().notificationEvents(notificationEvents);
            return this;
        }

        /**
         * A SNS topic to send vault events to.
         * <p>
         * Default: - no notifications
         * <p>
         * @return {@code this}
         * @see <a href="https://docs.aws.amazon.com/aws-backup/latest/devguide/sns-notifications.html">https://docs.aws.amazon.com/aws-backup/latest/devguide/sns-notifications.html</a>
         * @param notificationTopic A SNS topic to send vault events to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder notificationTopic(final software.amazon.awscdk.services.sns.ITopic notificationTopic) {
            this.props().notificationTopic(notificationTopic);
            return this;
        }

        /**
         * The removal policy to apply to the vault.
         * <p>
         * Note that removing a vault
         * that contains recovery points will fail.
         * <p>
         * Default: RemovalPolicy.RETAIN
         * <p>
         * @return {@code this}
         * @param removalPolicy The removal policy to apply to the vault. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder removalPolicy(final software.amazon.awscdk.RemovalPolicy removalPolicy) {
            this.props().removalPolicy(removalPolicy);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awscdk.services.backup.BackupVault}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.backup.BackupVault build() {
            return new software.amazon.awscdk.services.backup.BackupVault(
                this.scope,
                this.id,
                this.props != null ? this.props.build() : null
            );
        }

        private software.amazon.awscdk.services.backup.BackupVaultProps.Builder props() {
            if (this.props == null) {
                this.props = new software.amazon.awscdk.services.backup.BackupVaultProps.Builder();
            }
            return this.props;
        }
    }
}

==> aws-cdk-lib-2.225.0-sources.jar: software/amazon/awscdk/services/backup/BackupVault.java <==
package software.amazon.awscdk.services.backup;

/**
 * A backup vault.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * IBackupVault importedVault = BackupVault.fromBackupVaultName(this, "Vault", "myVaultName");
 * Role role = Role.Builder.create(this, "Access Role").assumedBy(new ServicePrincipal("lambda.amazonaws.com")).build();
 * importedVault.grant(role, "backup:StartBackupJob");
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-11-17T14:40:45.929Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_backup.BackupVault")
public class BackupVault extends software.amazon.awscdk.Resource implements software.amazon.awscdk.services.backup.IBackupVault {

    protected BackupVault(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected BackupVault(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        PROPERTY_INJECTION_ID = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.backup.BackupVault.class, "PROPERTY_INJECTION_ID", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public BackupVault(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.backup.BackupVaultProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), props });
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public BackupVault(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required") });
    }

    /**
     * Import an existing backup vault by arn.
     * <p>
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param backupVaultArn This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.backup.IBackupVault fromBackupVaultArn(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String backupVaultArn) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.backup.BackupVault.class, "fromBackupVaultArn", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.backup.IBackupVault.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(backupVaultArn, "backupVaultArn is required") });
    }

    /**
     * Import an existing backup vault by name.
     * <p>
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param backupVaultName This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.backup.IBackupVault fromBackupVaultName(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String backupVaultName) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.backup.BackupVault.class, "fromBackupVaultName", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.backup.IBackupVault.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(backupVaultName, "backupVaultName is required") });
    }

    /**
     * Adds a statement to the vault access policy.
     * <p>
     * @param statement This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void addToAccessPolicy(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.iam.PolicyStatement statement) {
        software.amazon.jsii.Kernel.call(this, "addToAccessPolicy", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(statement, "statement is required") });
    }

    /**
     * Adds a statement to the vault access policy that prevents anyone from deleting a recovery point.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void blockRecoveryPointDeletion() {
        software.amazon.jsii.Kernel.call(this, "blockRecoveryPointDeletion", software.amazon.jsii.NativeType.VOID);
    }

    /**
     * Grant the actions defined in actions to the given grantee on this Backup Vault resource.
     * <p>
     * @param grantee Principal to grant right to. This parameter is required.
     * @param actions The actions to grant. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.iam.Grant grant(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.iam.IGrantable grantee, final @org.jetbrains.annotations.NotNull java.lang.String... actions) {
        return software.amazon.jsii.Kernel.call(this, "grant", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.iam.Grant.class), java.util.stream.Stream.concat(java.util.Arrays.<Object>stream(new Object[] { java.util.Objects.requireNonNull(grantee, "grantee is required") }), java.util.Arrays.<Object>stream(actions)).toArray(Object[]::new));
    }

    /**
     * Uniquely identifies this class.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String PROPERTY_INJECTION_ID;

    /**
     * The ARN of the backup vault.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getBackupVaultArn() {
        return software.amazon.jsii.Kernel.get(this, "backupVaultArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * The name of a logical container where backups are stored.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getBackupVaultName() {
        return software.amazon.jsii.Kernel.get(this, "backupVaultName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.backup.BackupVault}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.backup.BackupVault> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private software.amazon.awscdk.services.backup.BackupVaultProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
        }

        /**
         * A resource-based policy that is used to manage access permissions on the backup vault.
         * <p>
         * Default: - access is not restricted
         * <p>
         * @return {@code this}
         * @param accessPolicy A resource-based policy that is used to manage access permissions on the backup vault. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder accessPolicy(final software.amazon.awscdk.services.iam.PolicyDocument accessPolicy) {
            this.props().accessPolicy(accessPolicy);
            return this;
        }

        /**
         * The name of a logical container where backups are stored.
         * <p>
         * Backup vaults
         * are identified by names that are unique to the account used to create
         * them and the AWS Region where they are created.
         * <p>
         * Default: - A CDK generated name
         * <p>
         * @return {@code this}
         * @param backupVaultName The name of a logical container where backups are stored. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder backupVaultName(final java.lang.String backupVaultName) {
            this.props().backupVaultName(backupVaultName);
            return this;
        }

        /**
         * Whether to add statements to the vault access policy that prevents anyone from deleting a recovery point.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param blockRecoveryPointDeletion Whether to add statements to the vault access policy that prevents anyone from deleting a recovery point. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder blockRecoveryPointDeletion(final java.lang.Boolean blockRecoveryPointDeletion) {
            this.props().blockRecoveryPointDeletion(blockRecoveryPointDeletion);
            return this;
        }

        /**
         * The server-side encryption key to use to protect your backups.
         * <p>
         * Default: - an Amazon managed KMS key
         * <p>
         * @return {@code this}
         * @param encryptionKey The server-side encryption key to use to protect your backups. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder encryptionKey(final software.amazon.awscdk.interfaces.kms.IKeyRef encryptionKey) {
            this.props().encryptionKey(encryptionKey);
            return this;
        }

        /**
         * Configuration for AWS Backup Vault Lock.
         * <p>
         * Default: - AWS Backup Vault Lock is disabled
         * <p>
         * @return {@code this}
         * @see <a href="https://docs.aws.amazon.com/aws-backup/latest/devguide/vault-lock.html">https://docs.aws.amazon.com/aws-backup/latest/devguide/vault-lock.html</a>
         * @param lockConfiguration Configuration for AWS Backup Vault Lock. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder lockConfiguration(final software.amazon.awscdk.services.backup.LockConfiguration lockConfiguration) {
            this.props().lockConfiguration(lockConfiguration);
            return this;
        }

        /**
         * The vault events to send.
         * <p>
         * Default: - all vault events if `notificationTopic` is defined
         * <p>
         * @return {@code this}
         * @see <a href="https://docs.aws.amazon.com/aws-backup/latest/devguide/sns-notifications.html">https://docs.aws.amazon.com/aws-backup/latest/devguide/sns-notifications.html</a>
         * @param notificationEvents The vault events to send. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder notificationEvents(final java.util.List<? extends software.amazon.awscdk.services.backup.BackupVaultEvents> notificationEvents) {
            this.props().notificationEvents(notificationEvents);
            return this;
        }

        /**
         * A SNS topic to send vault events to.
         * <p>
         * Default: - no notifications
         * <p>
         * @return {@code this}
         * @see <a href="https://docs.aws.amazon.com/aws-backup/latest/devguide/sns-notifications.html">https://docs.aws.amazon.com/aws-backup/latest/devguide/sns-notifications.html</a>
         * @param notificationTopic A SNS topic to send vault events to. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder notificationTopic(final software.amazon.awscdk.services.sns.ITopic notificationTopic) {
            this.props().notificationTopic(notificationTopic);
            return this;
        }

        /**
         * The removal policy to apply to the vault.
         * <p>
         * Note that removing a vault
         * that contains recovery points will fail.
         * <p>
         * Default: RemovalPolicy.RETAIN
         * <p>
         * @return {@code this}
         * @param removalPolicy The removal policy to apply to the vault. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder removalPolicy(final software.amazon.awscdk.RemovalPolicy removalPolicy) {
            this.props().removalPolicy(removalPolicy);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awscdk.services.backup.BackupVault}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.backup.BackupVault build() {
            return new software.amazon.awscdk.services.backup.BackupVault(
                this.scope,
                this.id,
                this.props != null ? this.props.build() : null
            );
        }

        private software.amazon.awscdk.services.backup.BackupVaultProps.Builder props() {
            if (this.props == null) {
                this.props = new software.amazon.awscdk.services.backup.BackupVaultProps.Builder();
            }
            return this.props;
        }
    }
}
